USE SSISDB
GO

/*
	Script name: 140 Execute Large Loads in Catalog
	Author: Tim Mitchell (tmitchell@tyleris.com)
	Date: 1/25/2021

	Purpose: This package will execute 3 packages, each of which uses
			a slightly different design pattern to accomplish the same
			load objective. A subsequent script can then be used to
			measure performance of each design pattern.

			Set the @NumberOfExecutionsPerPackage variable to define
			how many times each package is executed. Note that it takes
			around 25-50 for each package to run, so you'll want to 
			run this ahead of time and not during the presentation.

	Change log:
		-- 
*/

DECLARE @NumberOfExecutionsPerPackage INT = 7

DECLARE @counter INT = 0
DECLARE @execution_id BIGINT 

WHILE @counter < @NumberOfExecutionsPerPackage

BEGIN

	-- 100 Large load
	EXEC [catalog].[create_execution] @package_name=N'090 Large load.dtsx', @execution_id=@execution_id OUTPUT, @folder_name=N'SSIS Performance', @project_name=N'SSISPerformance', @use32bitruntime=False, @reference_id=NULL, @runinscaleout=False

	EXEC [catalog].[set_execution_parameter_value] @execution_id,  @object_type=50, @parameter_name=N'SYNCHRONIZED', @parameter_value=1

	EXEC [catalog].[start_execution] @execution_id

	RAISERROR('090 Large load.dtsx executed', 10, 1) WITH NOWAIT 


	-- 110 Large parallel
	EXEC [catalog].[create_execution] @package_name=N'091 Large parallel.dtsx', @execution_id=@execution_id OUTPUT, @folder_name=N'SSIS Performance', @project_name=N'SSISPerformance', @use32bitruntime=False, @reference_id=NULL, @runinscaleout=False

	EXEC [catalog].[set_execution_parameter_value] @execution_id,  @object_type=50, @parameter_name=N'SYNCHRONIZED', @parameter_value=1

	EXEC [catalog].[start_execution] @execution_id

	RAISERROR('091 Large parallel.dtsx executed', 10, 1) WITH NOWAIT 


	-- 120 Large parallel 1
	EXEC [catalog].[create_execution] @package_name=N'092 Large parallel 1.dtsx', @execution_id=@execution_id OUTPUT, @folder_name=N'SSIS Performance', @project_name=N'SSISPerformance', @use32bitruntime=False, @reference_id=NULL, @runinscaleout=False

	EXEC [catalog].[set_execution_parameter_value] @execution_id,  @object_type=50, @parameter_name=N'SYNCHRONIZED', @parameter_value=1

	EXEC [catalog].[start_execution] @execution_id

	RAISERROR('092 Large parallel 1.dtsx executed', 10, 1) WITH NOWAIT 

	
	SET @counter += 1

	DECLARE @msg VARCHAR(100) = 'Loop ' + CAST(@counter AS VARCHAR(5)) + ' completed.'

	RAISERROR(@msg, 10, 1) WITH NOWAIT
	
	
END