USE SSISDB
GO

/*
	Script name: 150 Show Catalog Package Performance
	Author: Tim Mitchell (tmitchell@tyleris.com)
	Date: 1/25/2021

	Purpose: This script shows performance runtimes for the packages
			executed in the previous script.

	Change log:
		-- 
*/


WITH t AS (
	SELECT folder_name, project_name, package_name
		, DATEDIFF(SECOND, CAST(start_time AS DATETIME), COALESCE(CAST(end_time AS DATETIME), GETDATE())) [duration]
	FROM catalog.executions
	WHERE folder_name = 'SSIS Performance'
	AND package_name LIKE '09%'
)

SELECT package_name
	, MIN(duration) [MinDuration]
	, MAX(duration) [MaxDuration]
	, AVG(duration) [AverageDuration]
	, COUNT(*) [Count]
FROM t
GROUP BY t.package_name


